@@ -21,8 +21,7 @@
 #include <stdarg.h>
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include <epiphany/ephy-embed-container.h>
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 #include "ephy-file-helpers.h"
 #include "ephy-actions-extension.h"
 #include "ephy-actions-extension-editor-dialog.h"
@@ -435,7 +434,8 @@ ephy_actions_extension_run_action (GtkAction *ui_action,
 			(GTK_WINDOW (window), GTK_DIALOG_DESTROY_WITH_PARENT,
 			 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 			 _("Could not run command"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(dialog), err->message);
+		gtk_message_dialog_format_secondary_text
+			(GTK_MESSAGE_DIALOG(dialog), err->message, NULL);
 		gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 		gtk_window_set_title (GTK_WINDOW(window), _("Could not Run Command"));
 		g_error_free (err);
@@ -497,7 +497,7 @@ ephy_actions_extension_document_popup_cb (GtkAction *action,
 	}
 
 	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-	url = ephy_embed_get_location (embed, TRUE);
+	url = ephy_web_view_get_location (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), TRUE);
 	ephy_actions_extension_run_action (action, window, url);
 	g_free (url);
 }
