@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-rss-extension.c 1677 2008-02-22 18:17:03Z xan $
+ *  $Id$
  */
 
 #include "config.h"
@@ -26,21 +26,9 @@
 
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-extension.h>
-#include <epiphany/ephy-dialog.h>
-#include <epiphany/ephy-window.h>
-#include <epiphany/ephy-statusbar.h>
-#include <epiphany/ephy-notebook.h>
-#include <epiphany/ephy-shell.h>
-#include <epiphany/ephy-embed-container.h>
+#include <epiphany/epiphany.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -301,16 +289,20 @@ impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
+	EphyWebView *view;
+
 	LOG ("Attach rss listener to tab");
 
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
+	view = EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed);
+
 	/* Notify when a new rss feed is parsed */
-	g_signal_connect_after (embed, "new-document-now",
+	g_signal_connect_after (view, "new-document-now",
 				G_CALLBACK (ephy_rss_ge_content_cb), window);
-	g_signal_connect_after (embed, "ge-feed-link",
+	g_signal_connect_after (view, "ge-feed-link",
 			    G_CALLBACK (ephy_rss_ge_feed_cb), window);
-	g_signal_connect (embed, "ge-context-menu",
+	g_signal_connect (view, "ge-context-menu",
 			    G_CALLBACK (ephy_rss_ge_context_cb), window);
 }
 
